PCB Environment: NavGrid Class Reference

PCB Environment 2

Loading...
Searching...
No Matches
Public Member Functions
NavGrid Class Reference

The grid-representation of the board. More...

`#include <NavGrid.hpp>`

Inheritance diagram for NavGrid:

## Public Member Functions
| NavGrid (PCBoard &)
const PCBoard & | getPCB () const
PCBoard & | getPCB ()
void | build ()
void | copyFrom (const NavGrid &)
const std::vector< NavPoint > & | getPoints () const
std::vector< NavPoint > & | getPoints ()
uint | getNumPoints () const
const NavPoint & | getPoint (uint i) const
const NavPoint & | getPoint (uint x, uint y, uint z) const
const NavPoint * | getPoint (const Point_2 &, uint z) const
const NavPoint * | getPoint (const Point_25 &v) const
NavPoint & | getPoint (uint i)
NavPoint & | getPoint (uint x, uint y, uint z)
NavPoint & | getPoint (const IPoint_3 &v)
NavPoint * | getPoint (const Point_2 &, uint z)
NavPoint * | getPoint (const Point_25 &v)
int | getDirectionStride (GridDirection d) const
uint32_t | getAddressOffset (const NavPoint *nav) const
NavPoint * | getPointFromAddressOffset (uint32_t)
const NavSpacings & | getSpacings () const
bool | setSpacings (const NavSpacings &)
void | initSpacingsForAnyRoutedTrack ()
void | resetKeepouts ()
void | resetKeepoutsRRR ()
void | rasterize (const Component &, const NavRasterizeParams &)
void | rasterize (const Pin &, const NavRasterizeParams &)
void | rasterizeCompound (const Pin &, const NavRasterizeParams &)
void | rasterize (const Connection &, const NavRasterizeParams &)
void | rasterizeLayoutAreaBorder (const NavRasterizeParams &)
void | rasterize (const Track &, const NavRasterizeParams &, uint rasterizeMask)
void | rasterize (const Path &, const NavRasterizeParams &)
void | getCosts (std::vector< float > &, uint index)
void | setCosts (uint index, float, const IBox_3 &)
void | setCosts (uint index, const float *, const IBox_3 &)
void | setCosts (uint index, const float *)
AStarCosts & | getAStarCosts ()
bool | findPathAStar (Connection &, const AStarCosts *)
Real | sumViolationArea (const Connection &)
uint16_t | nextRasterSeq ()
uint16_t | nextSearchSeq ()
uint16_t | getSearchSeq () const
std::string | str (const IBox_3 *=0) const
PyObject * | getPy (const IBox_3 &) const
PyObject * | getPathCoordinatesNumpy (const Track &) const
Public Member Functions inherited from UniformGrid25
| UniformGrid25 (Real edgeLen)
IVector_3 | getSize () const
uint | getSize (uint d) const
const Bbox_2 & | getBbox () const
Real | XCoord (int x) const
Real | YCoord (int y) const
Point_2 | Coords (const IPoint_2 &v) const
Point_2 | Coords (int x, int y) const
Point_25 | Coords (const IPoint_3 &v) const
Point_25 | Coords (int x, int y, uint z) const
Vector_2 | MidPointOffset () const
Real | MidPointX (int x) const
Real | MidPointY (int y) const
Point_2 | MidPoint (const IPoint_2 &v) const
Point_2 | MidPoint (int x, int y) const
Point_25 | MidPoint (const IPoint_3 &v) const
IVector_2 | HIndices (const Point_2 &v) const
int | XIndex (Real x, Real ex=0.0) const
int | YIndex (Real y, Real ey=0.0) const
uint | XIndexBounded (Real x, Real ex=0.0) const
uint | YIndexBounded (Real y, Real ey=0.0) const
uint | LinearIndex (uint z, uint y, uint x) const
uint | LinearIndex (const Point_25 &v) const
IBox_3 | getBox (const Bbox_2 &, uint z0=0, uint z1=std::numeric_limits< uint >::max()) const
Real | XfIndex (Real x, Real ex=0.0) const
Real | YfIndex (Real y, Real ey=0.0) const
uint | getNumPoints2D () const
uint | getNumPoints3D () const
bool | inside (const IPoint_3 &v) const
bool | inside (uint x, uint y, uint z) const
Point_25 | snapToMidPoint (const Point_25 &) const

## Additional Inherited Members
Data Fields inherited from UniformGrid25
const Real | EdgeLen
const Real | EdgeLen05
const Real | EdgeLenRcp
Protected Member Functions inherited from UniformGrid25
void | calcNumPoints3D ()
Protected Attributes inherited from UniformGrid25
Bbox_2 | mBbox
uint | mSize [3]
uint | mStrideZ
uint | mStrideY
uint | mNumPoints3D

## Detailed Description

The grid-representation of the board.

The documentation for this class was generated from the following file:

- /home/chr/devel/PhD/Environment/pub/PCBEnv/pcbenv/cxx/NavGrid.hpp